@@ -2,7 +2,7 @@
  * Routines for OMA UserPlane Location Protocol packet dissection
  * Copyright 2006, Anders Broman <anders.broman@ericsson.com>
  *
- * $Id: packet-ulp-template.c 22493 2007-08-13 16:44:35Z etxrab $
+ * $Id: packet-ulp-template.c 27390 2009-02-07 14:33:47Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -32,7 +32,6 @@
 
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/conversation.h>
 #include <epan/prefs.h>
 #include <epan/asn1.h>
 
@@ -40,7 +39,6 @@
 #include <string.h>
 
 #include "packet-per.h"
-#include <epan/emem.h>
 #include "packet-tcp.h"
 #include "packet-gsm_map.h"
 
@@ -48,14 +46,13 @@
 #define PSNAME "ULP"
 #define PFNAME "ulp"
 
-static dissector_handle_t ulp_handle = NULL;
-static dissector_handle_t rrlp_handle = NULL;
+static dissector_handle_t rrlp_handle;
 
 /* IANA Registered Ports  
  * oma-ulp         7275/tcp    OMA UserPlane Location
  * oma-ulp         7275/udp    OMA UserPlane Location
  */
-guint gbl_ulp_port = 7275;
+static guint gbl_ulp_port = 7275;
 
 /* Initialize the protocol and registered fields */
 static int proto_ulp = -1;
@@ -128,12 +125,12 @@ void proto_register_ulp(void) {
 		" To use this option, you must also enable \"Allow subdissectors to reassemble TCP streams\" in the TCP protocol settings.",
 		&ulp_desegment);
 
-	/* Register a configuration option for port */
-	prefs_register_uint_preference(ulp_module, "tcp.port",
-								   "ULP TCP Port",
-								   "Set the TCP port for Ulp messages(IANA registerd port is 7275)",
-								   10,
-								   &gbl_ulp_port);
+  /* Register a configuration option for port */
+  prefs_register_uint_preference(ulp_module, "tcp.port",
+                                 "ULP TCP Port",
+                                 "Set the TCP port for Ulp messages(IANA registerd port is 7275)",
+                                 10,
+                                 &gbl_ulp_port);
  
 }
 
@@ -142,15 +139,23 @@ void proto_register_ulp(void) {
 void
 proto_reg_handoff_ulp(void)
 {
+	static gboolean initialized = FALSE;
+	static dissector_handle_t ulp_handle;
+	static guint local_ulp_port;
 
-	ulp_handle = create_dissector_handle(dissect_ulp_tcp, proto_ulp);
+	if (!initialized) {
+		ulp_handle = find_dissector("ulp");
+		dissector_add_string("media_type","application/oma-supl-ulp", ulp_handle);
+		rrlp_handle = find_dissector("rrlp");
+		initialized = TRUE;
+	} else {
+		dissector_delete("tcp.port", local_ulp_port, ulp_handle);
+	}
 
+	local_ulp_port = gbl_ulp_port;
 	dissector_add("tcp.port", gbl_ulp_port, ulp_handle);
 
 	/* application/oma-supl-ulp */
-	dissector_add_string("media_type","application/oma-supl-ulp", ulp_handle);
-
-	rrlp_handle = find_dissector("rrlp");
 
 }
 
