@@ -1,7 +1,7 @@
 /* Edit capture files.  We can delete packets, adjust timestamps, or
  * simply convert from one format to another format.
  *
- * $Id: editcap.c 28458 2009-05-23 20:29:12Z guy $
+ * $Id: editcap.c 33544 2010-07-15 21:30:11Z gerald $
  *
  * Originally written by Richard Sharpe.
  * Improved by Guy Harris.
@@ -334,6 +334,11 @@ set_time_adjustment(char *optarg)
   /* now collect the partial seconds, if any */
   if (*frac != '\0') {             /* chars left, so get fractional part */
     val = strtol(&(frac[1]), &end, 10);
+    /* if more than 6 fractional digits truncate to 6 */
+    if((end - &(frac[1])) > 6) {
+        frac[7] = 't'; /* 't' for truncate */
+        val = strtol(&(frac[1]), &end, 10);
+    }
     if (*frac != '.' || end == NULL || end == frac
         || val < 0 || val > ONE_MILLION || val == LONG_MIN || val == LONG_MAX) {
       fprintf(stderr, "editcap: \"%s\" isn't a valid time adjustment\n",
@@ -399,6 +404,11 @@ set_rel_time(char *optarg)
   /* now collect the partial seconds, if any */
   if (*frac != '\0') {             /* chars left, so get fractional part */
     val = strtol(&(frac[1]), &end, 10);
+    /* if more than 9 fractional digits truncate to 9 */
+    if((end - &(frac[1])) > 9) {
+        frac[10] = 't'; /* 't' for truncate */
+        val = strtol(&(frac[1]), &end, 10);
+    }
     if (*frac != '.' || end == NULL || end == frac
         || val < 0 || val > ONE_BILLION || val == LONG_MIN || val == LONG_MAX) {
       fprintf(stderr, "3: editcap: \"%s\" isn't a valid rel time value\n",
@@ -986,6 +996,7 @@ main(int argc, char *argv[])
         pdh = wtap_dump_open(filename, out_file_type,
             out_frame_type, wtap_snapshot_length(wth),
             FALSE /* compressed */, &err);
+fprintf(stderr, "pdh1: %p\n", pdh);
         if (pdh == NULL) {  
           fprintf(stderr, "editcap: Can't open or create %s: %s\n", filename,
                   wtap_strerror(err));
@@ -1017,6 +1028,7 @@ main(int argc, char *argv[])
           pdh = wtap_dump_open(filename, out_file_type,
              out_frame_type, wtap_snapshot_length(wth), FALSE /* compressed */, &err);
 
+fprintf(stderr, "pdh2: %p\n", pdh);
           if (pdh == NULL) {
             fprintf(stderr, "editcap: Can't open or create %s: %s\n", filename,
               wtap_strerror(err));
@@ -1230,7 +1242,6 @@ main(int argc, char *argv[])
       count++;
     }
 
-    g_free(filename);
     g_free(fprefix);
     g_free(fsuffix);
 
@@ -1250,6 +1261,20 @@ main(int argc, char *argv[])
       }
     }
 
+    if (!pdh) {
+      /* No valid packages found, open the outfile so we can write an empty header */
+      g_free (filename);
+      filename = g_strdup(argv[optind+1]);
+
+      pdh = wtap_dump_open(filename, out_file_type,
+			   out_frame_type, wtap_snapshot_length(wth), FALSE /* compressed */, &err);
+      if (pdh == NULL) {
+	fprintf(stderr, "editcap: Can't open or create %s: %s\n", filename, 
+		wtap_strerror(err));
+	exit(2);
+      }
+    }
+
     if (!wtap_dump_close(pdh, &err)) {
 
       fprintf(stderr, "editcap: Error writing to %s: %s\n", filename,
@@ -1257,6 +1282,7 @@ main(int argc, char *argv[])
       exit(2);
 
     }
+    g_free(filename);
   }
 
   if (dup_detect) {
