@@ -3,7 +3,7 @@
  * Copyright 2003, Tim Potter <tpot@samba.org>
  * Copyright 2003, Ronnie Sahlberg,  added function dissectors
  *
- * $Id: packet-dcerpc-svcctl.c 19232 2006-09-14 12:01:18Z sahlberg $
+ * $Id: packet-dcerpc-svcctl.c 22703 2007-08-28 11:45:08Z sahlberg $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -117,7 +117,7 @@ svcctl_dissect_OpenSCManager_rqst(tvbuff_t *tvb, int offset,
 {
 	dcerpc_info *di = (dcerpc_info *)pinfo->private_data;
 	dcerpc_call_value *dcv = (dcerpc_call_value *)di->call_data;
-	char *mn, *dn;
+	const char *mn, *dn;
 
 	/* MachineName */
 	dcv->private_data=NULL;
@@ -177,7 +177,7 @@ svcctl_dissect_OpenSCManager_reply(tvbuff_t *tvb, int offset,
 		tvb, offset, pinfo, tree, drep, hf_svcctl_rc, &status);
 
 	if( status == 0 ){
-		char *pol_name;
+		const char *pol_name;
 
 		if (dcv->se_data){
 			pol_name = ep_strdup_printf(
@@ -186,7 +186,7 @@ svcctl_dissect_OpenSCManager_reply(tvbuff_t *tvb, int offset,
 			pol_name = "Unknown OpenSCManagerW() handle";
 		}
 		if(!pinfo->fd->flags.visited){
-			dcerpc_smb_store_pol_name(&policy_hnd, pinfo, pol_name);
+			dcerpc_store_polhnd_name(&policy_hnd, pinfo, pol_name);
 		}
 
 		if(hnd_item)
@@ -203,7 +203,7 @@ svcctl_dissect_OpenSCManagerW_rqst(tvbuff_t *tvb, int offset,
 {
 	dcerpc_info *di = (dcerpc_info *)pinfo->private_data;
 	dcerpc_call_value *dcv = (dcerpc_call_value *)di->call_data;
-	char *mn, *dn;
+	const char *mn, *dn;
 
 	/* MachineName */
 	dcv->private_data=NULL;
@@ -263,7 +263,7 @@ svcctl_dissect_OpenSCManagerW_reply(tvbuff_t *tvb, int offset,
 		tvb, offset, pinfo, tree, drep, hf_svcctl_rc, &status);
 
 	if( status == 0 ){
-		char *pol_name;
+		const char *pol_name;
 
 		if (dcv->se_data){
 			pol_name = ep_strdup_printf(
@@ -272,7 +272,7 @@ svcctl_dissect_OpenSCManagerW_reply(tvbuff_t *tvb, int offset,
 			pol_name = "Unknown OpenSCManagerW() handle";
 		}
 		if(!pinfo->fd->flags.visited){
-			dcerpc_smb_store_pol_name(&policy_hnd, pinfo, pol_name);
+			dcerpc_store_polhnd_name(&policy_hnd, pinfo, pol_name);
 		}
 
 		if(hnd_item)
@@ -303,7 +303,7 @@ svcctl_dissect_CloseServiceHandle_rqst(tvbuff_t *tvb, int offset,
 		tvb, offset, pinfo, tree, drep, hf_svcctl_hnd, &policy_hnd,
 		NULL, FALSE, TRUE);
 
-	dcerpc_smb_fetch_pol(&policy_hnd, &pol_name, NULL, NULL,
+	dcerpc_fetch_polhnd_data(&policy_hnd, &pol_name, NULL, NULL, NULL,
 			     pinfo->fd->num);
 
 	if (check_col(pinfo->cinfo, COL_INFO) && pol_name)
