@@ -1,9 +1,9 @@
-/* packet-vcdu.c
- * Routines for VCDU dissection
+/* packet-ehs.c
+ * Routines for "Enhanced HSC System" (EHS) dissection
  * Copyright 2000, Scott Hovis scott.hovis@ums.msfc.nasa.gov
  * Enhanced 2008, Matt Dunkle Matthew.L.Dunkle@nasa.gov
  *
- * $Id: packet-ehs.c 27794 2009-03-19 01:54:09Z wmeier $
+ * $Id: packet-ehs.c 28319 2009-05-08 21:58:10Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.com>
@@ -350,11 +350,10 @@ static const value_string ehs_secondary_header_tdm_end_of_data_flag[] =
   { 0, NULL }
 };
 
-static const value_string ehs_secondary_header_tdm_aoslos_flag[] =
+static const true_false_string ehs_tfs_secondary_header_tdm_aoslos_flag =
 {
-  { 0, "AOS" },
-  { 1, "LOS" },
-  { 0, NULL }
+   "AOS" ,
+   "LOS"
 };
 
 static const value_string ehs_secondary_header_tdm_data_status[] =
@@ -1479,7 +1478,7 @@ proto_register_ehs(void)
 		},
                 { &hf_ehs_sh_tdm_aoslos_flag,
 			{ "AOS/LOS Flag", "ehs2.tdm_aoslos_flag",
-			FT_BOOLEAN, 8, VALS(ehs_secondary_header_tdm_aoslos_flag), 0x08,
+                          FT_BOOLEAN, 8, TFS(&ehs_tfs_secondary_header_tdm_aoslos_flag), 0x08,
 			NULL, HFILL }
 		},
                 { &hf_ehs_sh_tdm_override_errors_flag,
