@@ -3,7 +3,7 @@
  * This decoder is for FC-SB3 version 1.4
  * Copyright 2003, Dinesh G Dutt <ddutt@cisco.com>
  *
- * $Id: packet-fcsb3.c 26089 2008-08-25 22:06:20Z wmeier $
+ * $Id: packet-fcsb3.c 28412 2009-05-19 17:16:14Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -300,7 +300,7 @@ dissect_iui_flags (proto_tree *parent_tree, tvbuff_t *tvb, int offset, guint16 f
 	flags&=(~( 0x08 ));
 
         proto_tree_add_item (tree, hf_sbccs_iui_val, tvb, offset, 1, 0);
-	proto_item_append_text(item, val_to_str (flags & 0x7, fc_sbccs_iu_val, "0x%x"));
+	proto_item_append_text(item, "%s", val_to_str (flags & 0x7, fc_sbccs_iu_val, "0x%x"));
 	flags&=(~( 0x07 ));
 }
 
@@ -549,7 +549,7 @@ dissect_status_flags (proto_tree *parent_tree, tvbuff_t *tvb, int offset, guint8
 
 
         proto_tree_add_item (tree, hf_sbccs_dib_statusflags_ffc, tvb, offset, 1, 0);
-	proto_item_append_text(item, val_to_str ((flags>>5)&0x07, status_ffc_val, "Reserved:0x%x"));
+	proto_item_append_text(item, "%s", val_to_str ((flags>>5)&0x07, status_ffc_val, "Reserved:0x%x"));
 	flags&=(~( 0xE0 ));
 
 	proto_tree_add_boolean(tree, hf_sbccs_dib_statusflags_ci, tvb, offset, 1, flags);
@@ -1016,6 +1016,7 @@ static void dissect_fc_sbccs (tvbuff_t *tvb, packet_info *pinfo,
     tvbuff_t *next_tvb;
     conversation_t *conversation;
     sb3_task_id_t task_key;
+    void* pd_save;
         
     /* Make entries in Protocol column and Info column on summary display */
     if (check_col(pinfo->cinfo, COL_PROTOCOL)) 
@@ -1034,6 +1035,7 @@ static void dissect_fc_sbccs (tvbuff_t *tvb, packet_info *pinfo,
     conversation = find_conversation (pinfo->fd->num, &pinfo->src, &pinfo->dst,
                                       PT_SBCCS, ch_cu_id, dev_addr, 0);
                                       
+    pd_save = pinfo->private_data;
     if (conversation) {
         task_key.conv_id = conversation->index;
         task_key.task_id = ccw;
@@ -1097,6 +1099,7 @@ static void dissect_fc_sbccs (tvbuff_t *tvb, packet_info *pinfo,
                                    -1, -1);
         call_dissector (data_handle, next_tvb, pinfo, tree);
     }
+    pinfo->private_data = pd_save;
 }
 
 /* Register the protocol with Wireshark */
