@@ -3,7 +3,7 @@
  * Copyright 2009, Vasantha Crabb <vcrabb@managesoft.com.au>
  *  and Chris Adams <cadams@managesoft.com.au>
  *
- * $Id: packet-ldss.c 31596 2010-01-20 22:53:59Z gerald $
+ * $Id: packet-ldss.c 32215 2010-03-16 23:22:42Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -701,7 +701,7 @@ dissect_ldss_transfer (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			/* Be nice and uncompress the file data. */
 			if (compression == COMPRESSION_GZIP) {
 				tvbuff_t *uncomp_tvb = NULL;
-				uncomp_tvb = tvb_child_uncompress(NULL, tvb, 0, tvb_length(tvb));
+				uncomp_tvb = tvb_uncompress(tvb, 0, tvb_length(tvb));
 				if (uncomp_tvb != NULL) {
 					ti = proto_tree_add_bytes_format_value(ldss_tree, hf_ldss_file_data,
 									       uncomp_tvb, 0, tvb_length(uncomp_tvb),
