@@ -1,5 +1,5 @@
 /*
- * $Id: ftype-guid.c 20472 2007-01-18 11:02:26Z martinm $
+ * $Id: ftype-guid.c 33115 2010-06-06 22:13:16Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -66,7 +66,7 @@ get_guid(char *s, e_guid_t *guid)
     p = s;
     strncpy(digits, p, 8); 
     digits[8] = '\0';
-    guid->data1 = strtoul(digits, NULL, 16);
+    guid->data1 = (guint32)strtoul(digits, NULL, 16);
     p += 9;
     strncpy(digits, p, 4); 
     digits[4] = '\0';
@@ -130,7 +130,7 @@ ftype_register_guid(void)
 
     static ftype_t guid_type = {
         FT_GUID,              /* ftype */
-        "GUID",              /* name */
+        "FT_GUID",           /* name */
         "Globally Unique Identifier",            /* pretty_name */
         GUID_LEN,            /* wire_size */
         NULL,                /* new_value */
