@@ -5,7 +5,7 @@
  *
  * (c) 2006, Luis E. Garcia Ontanon <luis@ontanon.org>
  *
- * $Id: wslua_field.c 26749 2008-11-11 13:32:51Z rbalint $
+ * $Id: wslua_field.c 32215 2010-03-16 23:22:42Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -63,6 +63,9 @@ WSLUA_METAMETHOD FieldInfo__call(lua_State* L) {
 		case FT_NONE:
 			lua_pushnil(L);
 			return 1;
+		case FT_BOOLEAN:
+			lua_pushboolean(L,(int)fvalue_get_uinteger(&(fi->value)));
+			return 1;
 		case FT_UINT8:
 		case FT_UINT16:
 		case FT_UINT24:
@@ -150,7 +153,7 @@ WSLUA_METAMETHOD FieldInfo__call(lua_State* L) {
 }
 
 WSLUA_METAMETHOD FieldInfo__tostring(lua_State* L) {
-	/* the string representation of the field */
+	/* The string representation of the field */
 	FieldInfo fi = checkFieldInfo(L,1);
 	if (fi) {
 		if (fi->value.ftype->val_to_string_repr) {
@@ -166,7 +169,7 @@ WSLUA_METAMETHOD FieldInfo__tostring(lua_State* L) {
 }
 
 int FieldInfo_get_range(lua_State* L) {
-	/* the TvbRange covering this field */
+	/* The TvbRange covering this field */
 	FieldInfo fi = checkFieldInfo(L,1);
 	TvbRange r = ep_alloc(sizeof(struct _wslua_tvbrange));
 	r->tvb = ep_alloc(sizeof(struct _wslua_tvb));
@@ -187,7 +190,7 @@ int FieldInfo_get_generated(lua_State* L) {
 }
 
 int FieldInfo_get_name(lua_State* L) {
-	/* the filter name of this field. */
+	/* The filter name of this field. */
 	FieldInfo fi = checkFieldInfo(L,1);
 	lua_pushstring(L,fi->hfinfo->abbrev);
 	return 1;
@@ -231,12 +234,12 @@ static int FieldInfo__index(lua_State* L) {
 }
 
 WSLUA_METAMETHOD FieldInfo__eq(lua_State* L) {
-	/* checks whether lhs is within rhs */
+	/* Checks whether lhs is within rhs */
 	FieldInfo l = checkFieldInfo(L,1);
 	FieldInfo r = checkFieldInfo(L,2);
 
 	if (l->ds_tvb != r->ds_tvb)
-		WSLUA_ERROR(FieldInfo__eq,"data source must be the same for both fields");
+		WSLUA_ERROR(FieldInfo__eq,"Data source must be the same for both fields");
 
 	if (l->start <= r->start && r->start + r->length <= l->start + r->length) {
 		lua_pushboolean(L,1);
@@ -247,7 +250,7 @@ WSLUA_METAMETHOD FieldInfo__eq(lua_State* L) {
 }
 
 WSLUA_METAMETHOD FieldInfo__le(lua_State* L) {
-	/* checks whether the end byte of lhs is before the end of rhs */
+	/* Checks whether the end byte of lhs is before the end of rhs */
 	FieldInfo l = checkFieldInfo(L,1);
 	FieldInfo r = checkFieldInfo(L,2);
 
@@ -263,12 +266,12 @@ WSLUA_METAMETHOD FieldInfo__le(lua_State* L) {
 }
 
 WSLUA_METAMETHOD FieldInfo__lt(lua_State* L) {
-	/* checks whether the end byte of rhs is before the beginning of rhs */
+	/* Checks whether the end byte of rhs is before the beginning of rhs */
 	FieldInfo l = checkFieldInfo(L,1);
 	FieldInfo r = checkFieldInfo(L,2);
 
 	if (l->ds_tvb != r->ds_tvb)
-		WSLUA_ERROR(FieldInfo__eq,"data source must be the same for both fields");
+		WSLUA_ERROR(FieldInfo__eq,"Data source must be the same for both fields");
 
 	if ( r->start + r->length < l->start ) {
 		lua_pushboolean(L,1);
@@ -298,7 +301,7 @@ int FieldInfo_register(lua_State* L) {
 
 
 WSLUA_FUNCTION wslua_all_field_infos(lua_State* L) {
-	/* obtain all fields from the current tree */
+	/* Obtain all fields from the current tree */
 	GPtrArray* found;
 	int items_found = 0;
 	guint i;
@@ -395,7 +398,7 @@ WSLUA_CONSTRUCTOR Field_new(lua_State *L) {
 		WSLUA_ARG_ERROR(Field_new,FIELDNAME,"a field with this name must exist");
 
     if (!wanted_fields)
-		WSLUA_ERROR(Field_get,"a Field extractor must be defined before Taps or Dissectors get called");
+		WSLUA_ERROR(Field_get,"A Field extractor must be defined before Taps or Dissectors get called");
 
     f = g_malloc(sizeof(void*));
     *f = (header_field_info*)g_strdup(name); /* cheating */
@@ -407,7 +410,7 @@ WSLUA_CONSTRUCTOR Field_new(lua_State *L) {
 }
 
 WSLUA_METAMETHOD Field__call (lua_State* L) {
-	/* obtain all values (see FieldInfo) for this field. */
+	/* Obtain all values (see FieldInfo) for this field. */
     Field f = checkField(L,1);
     header_field_info* in = *f;
 	int items_found = 0;
@@ -418,7 +421,7 @@ WSLUA_METAMETHOD Field__call (lua_State* L) {
     }
 
     if (! lua_pinfo ) {
-        WSLUA_ERROR(Field__call,"fields cannot be used outside dissectors or taps");
+        WSLUA_ERROR(Field__call,"Fields cannot be used outside dissectors or taps");
         return 0;
     }
 
@@ -437,7 +440,7 @@ WSLUA_METAMETHOD Field__call (lua_State* L) {
 }
 
 WSLUA_METAMETHOD Field_tostring(lua_State* L) {
-	/* obtain a srting with the field name */
+	/* Obtain a srting with the field name */
     Field f = checkField(L,1);
 
     if ( !(f && *f) ) {
