@@ -1,7 +1,7 @@
 /* capture_info_dlg.c
  * Routines for packet capture info dialog
  *
- * $Id: capture_info_dlg.c 25986 2008-08-12 04:44:35Z etxrab $
+ * $Id: capture_info_dlg.c 28108 2009-04-21 16:57:52Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -85,7 +85,7 @@ pct(gint num, gint denom) {
   if (denom) {
     return (float) (num * 100.0 / denom);
   } else {
-    return 0.0;
+    return 0.0f;
   }
 }
 
@@ -316,7 +316,7 @@ capture_info    *cinfo)
   g_snprintf(label_str, sizeof(label_str), "%02ld:%02ld:%02ld",
            (long)(cinfo->running_time/3600), (long)((cinfo->running_time%3600)/60),
            (long)(cinfo->running_time%60));
-  gtk_label_set(GTK_LABEL(info->running_time_lb), label_str);
+    gtk_label_set_text(GTK_LABEL(info->running_time_lb), label_str);
 
   /* if we have new packets, update all rows */
   if (cinfo->new_packets) {
@@ -324,7 +324,7 @@ capture_info    *cinfo)
     for (i = 0; i < PACKET_COUNTS_SIZE; i++) {
         g_snprintf(label_str, sizeof(label_str), "%d",
                  *info->counts[i].value_ptr);
-        gtk_label_set(GTK_LABEL(info->counts[i].value_lb), label_str);
+         gtk_label_set_text(GTK_LABEL(info->counts[i].value_lb), label_str);
 
         /* don't try to update the "total" row progress bar */
         if (i != 0) {
@@ -335,7 +335,7 @@ capture_info    *cinfo)
         g_snprintf(label_str, sizeof(label_str), "%.1f%%",
                  pct(*info->counts[i].value_ptr, *info->counts[0].value_ptr));
 
-        gtk_label_set(GTK_LABEL(info->counts[i].percent_lb), label_str);
+         gtk_label_set_text(GTK_LABEL(info->counts[i].percent_lb), label_str);
     }
   }
 }
