@@ -3,7 +3,7 @@
  * Copyright 2008 Vincenzo Condoleo, Christophe Dirac, Reto Ruoss
  * supported by HSR (Hochschule Rapperswil) 
  *
- * $Id: compare_stat.c 28447 2009-05-22 13:08:54Z wmeier $
+ * $Id: compare_stat.c 29662 2009-09-01 22:36:30Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -405,7 +405,7 @@ call_foreach_merge_settings(gpointer value, gpointer arg)
 		if(fInfoTemp==NULL){
 			fprintf(stderr,"ERROR: start number not set correctly\n");
 		}
-		if(fmod(fInfoTemp->zebra_time.nsecs, 2)){
+		if(fInfoTemp && fmod(fInfoTemp->zebra_time.nsecs, 2)){
 			/*first file*/
 			cs->stop_packet_nr_first=cs->start_packet_nr_first+abs(cs->second_file_amount-(cs->start_packet_nr_second-cs->first_file_amount));
 			if(cs->stop_packet_nr_first>(tot_packet_amount-cs->second_file_amount)){
@@ -747,7 +747,9 @@ gtk_comparestat_init(const char *optarg, void* userdata _U_)
 	/* microsecond precision */
 	timestamp_set_precision(TS_PREC_AUTO_NSEC);
 
-	cs->win=window_new(GTK_WINDOW_TOPLEVEL, "compare-stat");
+	/* transient_for top_level */
+	cs->win=dlg_window_new("compare-stat");  
+	gtk_window_set_destroy_with_parent (GTK_WINDOW(cs->win), TRUE);
 	gtk_window_set_default_size(GTK_WINDOW(cs->win), 550, 400);
 	comparestat_set_title(cs);
 
