@@ -1,7 +1,7 @@
 /* proto_draw.c
  * Routines for GTK+ packet display
  *
- * $Id: main_proto_draw.c 27520 2009-02-23 15:30:15Z stig $
+ * $Id: main_proto_draw.c 32215 2010-03-16 23:22:42Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -49,6 +49,7 @@
 #include <epan/packet.h>
 #include <epan/charsets.h>
 #include <epan/prefs.h>
+#include <epan/filesystem.h>
 
 #include "../isprint.h"
 #include "../alert_box.h"
@@ -491,7 +492,7 @@ highlight_field(tvbuff_t *tvb, gint byte, GtkTreeView *tree_view,
     /* And position the window so the selection is visible.
      * Position the selection in the middle of the viewable
      * pane. */
-    gtk_tree_view_scroll_to_cell(tree_view, first_path, NULL, TRUE, 0.5, 0.0);
+    gtk_tree_view_scroll_to_cell(tree_view, first_path, NULL, TRUE, 0.5f, 0.0f);
 
     gtk_tree_path_free(first_path);
 
@@ -837,29 +838,42 @@ copy_hex_cb(GtkWidget * w _U_, gpointer data _U_, copy_data_type data_type)
 }
 
 /* save the current highlighted hex data */
-static void
+static gboolean
 savehex_save_clicked_cb(GtkWidget * w _U_, gpointer data _U_)
 {
         GtkWidget *bv;
 	int fd, start, end;
 	guint len;
 	const guint8 *data_p = NULL;
-	const char *file = NULL;
+	char *file;
 
 	file = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(savehex_dlg));
 
+#if 0 /* Not req'd: GtkFileChooserWidget currently being used won't return with a Null filename */
 	if (!file ||! *file) {
 		simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "Please enter a filename!");
-		return;
+		g_free(file);
+		return TRUE;
+	}
+#endif
+	if (test_for_directory(file) == EISDIR) {
+		/* It's a directory - set the file selection box to display that
+		   directory, and leave the selection box displayed. */
+		set_last_open_dir(file);
+		g_free(file);
+		file_selection_set_current_folder(savehex_dlg, get_last_open_dir());
+		gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(savehex_dlg), "");
+		return FALSE; /* do gtk_dialog_run again */
 	}
 
-	/* Must check if file name exists first */
+	/* XXX: Must check if file name exists first */
 
 	bv = get_notebook_bv_ptr(byte_nb_ptr);
 	if (bv == NULL) {
 		/* shouldn't happen */
 		simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "Could not find the corresponding text window!");
-		return;
+		g_free(file);
+		return TRUE;
 	}
 	/*
 	 * Retrieve the info we need
@@ -871,26 +885,34 @@ savehex_save_clicked_cb(GtkWidget * w _U_, gpointer data _U_)
 	if (data_p == NULL || start == -1 || start > end) {
 		simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
 		    "No data selected to save!");
-		return;
+		g_free(file);
+		return TRUE;
 	}
 
 	fd = ws_open(file, O_WRONLY|O_CREAT|O_TRUNC|O_BINARY, 0666);
 	if (fd == -1) {
 		open_failure_alert_box(file, errno, TRUE);
-		return;
+		g_free(file);
+		return TRUE;
 	}
 	if (ws_write(fd, data_p + start, end - start) < 0) {
 		write_failure_alert_box(file, errno);
 		ws_close(fd);
-		return;
+		g_free(file);
+		return TRUE;
 	}
 	if (ws_close(fd) < 0) {
 		write_failure_alert_box(file, errno);
-		return;
+		g_free(file);
+		return TRUE;
 	}
 
 	/* Get rid of the dialog box */
+	g_free(file);
+#if 0 /* being handled by caller  (for now) */
 	window_destroy(GTK_WIDGET(savehex_dlg));
+#endif
+	return TRUE;
 }
 
 /* Launch the dialog box to put up the file selection box etc */
@@ -925,32 +947,57 @@ void savehex_cb(GtkWidget * w _U_, gpointer data _U_)
 		return;
 	}
 
+#if 0  /* XXX: GtkFileChooserDialog/gtk_dialog_run currently being used is effectively modal so this is not req'd */
     /* if the window is already open, bring it to front */
 	if(savehex_dlg){
 		reactivate_window(savehex_dlg);
 		return;
 	}
-
+#endif
 	/*
 	 * Build the dialog box we need.
 	 */
     savehex_dlg = file_selection_new("Wireshark: Export Selected Packet Bytes", FILE_SELECTION_SAVE);
+#if GTK_CHECK_VERSION(2,8,0)
+    gtk_file_chooser_set_do_overwrite_confirmation(GTK_FILE_CHOOSER(savehex_dlg), TRUE);
+#endif
 
     /* label */
     label = g_strdup_printf("Will save %u %s of raw binary data to specified file.",
-        end - start, plurality(end - start, "byte", "bytes"));
+                            end - start, plurality(end - start, "byte", "bytes"));
     dlg_lb = gtk_label_new(label);
     g_free(label);
     file_selection_set_extra_widget(savehex_dlg, dlg_lb);
-	gtk_widget_show(dlg_lb);
+    gtk_widget_show(dlg_lb);
 
     g_signal_connect(savehex_dlg, "destroy", G_CALLBACK(savehex_dlg_destroy_cb), NULL);
 
+#if 0
     if (gtk_dialog_run(GTK_DIALOG(savehex_dlg)) == GTK_RESPONSE_ACCEPT) {
         savehex_save_clicked_cb(savehex_dlg, savehex_dlg);
     } else {
         window_destroy(savehex_dlg);
     }
+#endif
+    /* "Run" the GtkFileChooserDialog.                                              */
+    /* Upon exit: If "Accept" run the OK callback.                                  */
+    /*            If the OK callback returns with a FALSE status, re-run the dialog.*/
+    /*            If not accept (ie: cancel) destroy the window.                    */
+    /* XXX: If the OK callback pops up an alert box (eg: for an error) it *must*    */
+    /*      return with a TRUE status so that the dialog window will be destroyed.  */
+    /*      Trying to re-run the dialog after popping up an alert box will not work */
+    /*       since the user will not be able to dismiss the alert box.              */
+    /*      The (somewhat unfriendly) effect: the user must re-invoke the           */
+    /*      GtkFileChooserDialog whenever the OK callback pops up an alert box.     */
+    /*                                                                              */
+    /*      ToDo: use GtkFileChooserWidget in a dialog window instead of            */
+    /*            GtkFileChooserDialog.                                             */
+    while (gtk_dialog_run(GTK_DIALOG(savehex_dlg)) == GTK_RESPONSE_ACCEPT) {
+        if (savehex_save_clicked_cb(NULL, savehex_dlg)) {
+            break; /* we're done */
+        }
+    }
+    window_destroy(savehex_dlg);
 }
 
 
@@ -985,7 +1032,7 @@ packet_hex_print_common(GtkWidget *bv, const guint8 *pd, int len, int bstart,
   unsigned int   use_digits;
   gboolean       reverse, newreverse;
   GtkTextView   *bv_text_view = GTK_TEXT_VIEW(bv);
-  GtkTextBuffer *buf = gtk_text_view_get_buffer(bv_text_view);
+  GtkTextBuffer *buf;
   GtkTextIter    iter;
   const char    *revstyle;
   GtkTextMark   *mark = NULL;
@@ -998,10 +1045,28 @@ packet_hex_print_common(GtkWidget *bv, const guint8 *pd, int len, int bstart,
   int         progbar_nextstep;
   int         progbar_quantum;
 
+  buf = gtk_text_view_get_buffer(bv_text_view);
+  g_object_ref(buf);
+#if 0
+  gtk_text_view_set_buffer( bv_text_view, NULL);       /* XXX: Apparently not a good idea; If a progress_bar
+                                                        *      is displayed below in delayed_create_progress_dlg()
+                                                        *      there will then be a crash internally in the gtk library.
+                                                        *      (It appears that gtk_text_view_set_buffer
+                                                        *       queues a callback to be run when this
+                                                        *       thread is next idle. Unfortunately the call to
+                                                        *       gtk_main_iteration() in delayed_create_progress_dlg()
+                                                        *       causes the internal callback to be run which then 
+                                                        *       crashes (because the textview has no buffer ?))
+                                                        */  
+#endif
+  gtk_text_view_set_buffer( bv_text_view,
+                            gtk_text_buffer_new(NULL));/* attach a dummy buffer in place of the real buffer.
+                                                        * (XXX: Presumably this is done so there's no attempt
+                                                        *       to display the real buffer until it has been
+                                                        *       completely generated).
+                                                        */
   gtk_text_buffer_set_text(buf, "", 0);
   gtk_text_buffer_get_start_iter(buf, &iter);
-  g_object_ref(buf);
-  gtk_text_view_set_buffer( bv_text_view, NULL);
 
   /*
    * How many of the leading digits of the offset will we supply?
@@ -1028,7 +1093,7 @@ packet_hex_print_common(GtkWidget *bv, const guint8 *pd, int len, int bstart,
      bump that value by this amount. */
   progbar_quantum = len/N_PROGBAR_UPDATES;
   /* Progress so far. */
-  progbar_val = 0.0;
+  progbar_val = 0.0f;
 
   progbar_stop_flag = FALSE;
   g_get_current_time(&progbar_start_time);
