@@ -1,7 +1,7 @@
 /*
  * Copyright 2004, Irene Ruengeler <i.ruengeler [AT] fh-muenster.de>
  *
- * $Id: sctp_byte_graph_dlg.c 27800 2009-03-19 17:49:11Z wmeier $
+ * $Id: sctp_byte_graph_dlg.c 29099 2009-07-15 00:10:08Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1043,9 +1043,8 @@ static void init_sctp_graph_window(struct sctp_udata *u_data)
 
 	/* create the main window */
 
-	u_data->io->window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
-
-	gtk_widget_set_name(u_data->io->window, "SCTP Graphics");
+	u_data->io->window = dlg_window_new("SCTP Graphics");  /* transient_for top_level */
+	gtk_window_set_destroy_with_parent (GTK_WINDOW(u_data->io->window), TRUE);
 
 	vbox=gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(u_data->io->window), vbox);
