@@ -2,7 +2,7 @@
  * Routines to Dissect Appendix C TLV's
  * Copyright 2002, Anand V. Narwani <anand[AT]narwani.org>
  *
- * $Id: packet-tlv.c 18231 2006-05-28 16:32:49Z etxrab $
+ * $Id: packet-tlv.c 28318 2009-05-08 20:45:29Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -2101,708 +2101,708 @@ proto_register_docsis_tlv (void)
 /* Setup list of header fields  See Section 1.6.1 for details*/
   static hf_register_info hf[] = {
     {&hf_docsis_tlv,
-     {"TLV Data", "docsis.tlv",
+     {"TLV Data", "docsis_tlv",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "TLV Data", HFILL}
      },
     {&hf_docsis_tlv_down_freq,
-     {"1 Downstream Frequency", "docsis.tlv.downfreq",
+     {"1 Downstream Frequency", "docsis_tlv.downfreq",
       FT_UINT32, BASE_DEC, NULL, 0x0,
       "Downstream Frequency", HFILL}
      },
     {&hf_docsis_tlv_upstream_chid,
-     {"2 Upstream Channel ID", "docsis.tlv.upchid",
+     {"2 Upstream Channel ID", "docsis_tlv.upchid",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Service Identifier", HFILL}
      },
     {&hf_docsis_tlv_net_access,
-     {"3 Network Access", "docsis.tlv.netaccess",
-      FT_BOOLEAN, BASE_DEC, TFS (&on_off_tfs), 0x0,
+     {"3 Network Access", "docsis_tlv.netaccess",
+      FT_BOOLEAN, BASE_NONE, TFS (&on_off_tfs), 0x0,
       "Network Access TLV", HFILL}
      },
     {&hf_docsis_tlv_cos,
-     {"4 COS Encodings", "docsis.tlv.cos",
+     {"4 COS Encodings", "docsis_tlv.cos",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "4 COS Encodings", HFILL}
      },
     {&hf_docsis_tlv_cos_id,
-     {".1 Class ID", "docsis.tlv.cos.id",
+     {".1 Class ID", "docsis_tlv.cos.id",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Class ID", HFILL}
      },
     {&hf_docsis_tlv_cos_sid,
-     {".2 Service ID", "docsis.cos.sid",
+     {".2 Service ID", "docsis_tlv.cos.sid",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "Service ID", HFILL}
      },
     {&hf_docsis_tlv_cos_max_down,
-     {".2 Max Downstream Rate (bps)", "docsis.tlv.cos.maxdown",
+     {".2 Max Downstream Rate (bps)", "docsis_tlv.cos.maxdown",
       FT_UINT32, BASE_DEC, NULL, 0x0,
       "Max Downstream Rate", HFILL}
      },
     {&hf_docsis_tlv_cos_max_up,
-     {".3 Max Upstream Rate (bps)", "docsis.tlv.cos.maxup",
+     {".3 Max Upstream Rate (bps)", "docsis_tlv.cos.maxup",
       FT_UINT32, BASE_DEC, NULL, 0x0,
       "Max Upstream Rate", HFILL}
      },
     {&hf_docsis_tlv_cos_up_chnl_pri,
-     {".4 Upstream Channel Priority", "docsis.tlv.cos.upchnlpri",
+     {".4 Upstream Channel Priority", "docsis_tlv.cos.upchnlpri",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Upstream Channel Priority", HFILL}
      },
     {&hf_docsis_tlv_cos_min_grntd_up,
-     {".5 Guaranteed Upstream Rate", "docsis.tlv.cos.mingrntdup",
+     {".5 Guaranteed Upstream Rate", "docsis_tlv.cos.mingrntdup",
       FT_UINT32, BASE_DEC, NULL, 0x0,
       "Guaranteed Minimum Upstream Data Rate", HFILL}
      },
     {&hf_docsis_tlv_cos_max_up_burst,
-     {".6 Maximum Upstream Burst", "docsis.tlv.cos.maxupburst",
+     {".6 Maximum Upstream Burst", "docsis_tlv.cos.maxupburst",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "Maximum Upstream Burst", HFILL}
      },
     {&hf_docsis_tlv_cos_privacy_enable,
-     {".7 COS Privacy Enable", "docsis.tlv.cos.privacy_enable",
-      FT_BOOLEAN, BASE_DEC, TFS (&ena_dis_tfs), 0x0,
+     {".7 COS Privacy Enable", "docsis_tlv.cos.privacy_enable",
+      FT_BOOLEAN, BASE_NONE, TFS (&ena_dis_tfs), 0x0,
       "Class of Service Privacy Enable", HFILL}
      },
     {&hf_docsis_tlv_mcap,
-     {"5 Modem Capabilities", "docsis.tlv.mcap",
+     {"5 Modem Capabilities", "docsis_tlv.mcap",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Modem Capabilities", HFILL}
      },
     {&hf_docsis_tlv_mcap_concat,
-     {".1 Concatenation Support", "docsis.tlv.mcap.concat",
-      FT_BOOLEAN, BASE_DEC, TFS (&on_off_tfs), 0x0,
+     {".1 Concatenation Support", "docsis_tlv.mcap.concat",
+      FT_BOOLEAN, BASE_NONE, TFS (&on_off_tfs), 0x0,
       "Concatenation Support", HFILL}
      },
     {&hf_docsis_tlv_mcap_docs_ver,
-     {".2 Docsis Version", "docsis.tlv.map.docsver",
+     {".2 Docsis Version", "docsis_tlv.map.docsver",
       FT_UINT8, BASE_DEC, VALS (docs_ver_vals), 0x0,
       "DOCSIS Version", HFILL}
      },
     {&hf_docsis_tlv_mcap_frag,
-     {".3 Fragmentation Support", "docsis.tlv.mcap.frag",
-      FT_BOOLEAN, BASE_DEC, TFS (&on_off_tfs), 0x0,
+     {".3 Fragmentation Support", "docsis_tlv.mcap.frag",
+      FT_BOOLEAN, BASE_NONE, TFS (&on_off_tfs), 0x0,
       "Fragmentation Support", HFILL}
      },
     {&hf_docsis_tlv_mcap_phs,
-     {".4 PHS Support", "docsis.tlv.mcap.phs",
-      FT_BOOLEAN, BASE_DEC, TFS (&on_off_tfs), 0x0,
+     {".4 PHS Support", "docsis_tlv.mcap.phs",
+      FT_BOOLEAN, BASE_NONE, TFS (&on_off_tfs), 0x0,
       "PHS Support", HFILL}
      },
     {&hf_docsis_tlv_mcap_igmp,
-     {".5 IGMP Support", "docsis.tlv.mcap.igmp",
-      FT_BOOLEAN, BASE_DEC, TFS (&on_off_tfs), 0x0,
+     {".5 IGMP Support", "docsis_tlv.mcap.igmp",
+      FT_BOOLEAN, BASE_NONE, TFS (&on_off_tfs), 0x0,
       "IGMP Support", HFILL}
      },
     {&hf_docsis_tlv_mcap_privacy,
-     {".6 Privacy Support", "docsis.tlv.mcap.privacy",
-      FT_BOOLEAN, BASE_DEC, TFS (&on_off_tfs), 0x0,
+     {".6 Privacy Support", "docsis_tlv.mcap.privacy",
+      FT_BOOLEAN, BASE_NONE, TFS (&on_off_tfs), 0x0,
       "Privacy Support", HFILL}
      },
     {&hf_docsis_tlv_mcap_down_said,
-     {".7 # Downstream SAIDs Supported", "docsis.tlv.mcap.downsaid",
+     {".7 # Downstream SAIDs Supported", "docsis_tlv.mcap.downsaid",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Downstream Said Support", HFILL}
      },
     {&hf_docsis_tlv_mcap_up_sid,
-     {".8 # Upstream SAIDs Supported", "docsis.tlv.mcap.upsid",
+     {".8 # Upstream SAIDs Supported", "docsis_tlv.mcap.upsid",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Upstream SID Support", HFILL}
      },
     {&hf_docsis_tlv_mcap_8021P_filter,
-     {".9 802.1P Filtering Support", "docsis.tlv.mcap.dot1pfiltering",
+     {".9 802.1P Filtering Support", "docsis_tlv.mcap.dot1pfiltering",
       FT_UINT8, BASE_DEC, VALS (on_off_vals), 0x80,
       "802.1P Filtering Support", HFILL}
      },
     {&hf_docsis_tlv_mcap_8021Q_filter,
-     {".9 802.1Q Filtering Support", "docsis.tlv.mcap.dot1qfilt",
+     {".9 802.1Q Filtering Support", "docsis_tlv.mcap.dot1qfilt",
       FT_UINT8, BASE_DEC, VALS (on_off_vals), 0x40,
       "802.1Q Filtering Support", HFILL}
      },
     {&hf_docsis_tlv_mcap_xmit_eq_taps_per_sym,
-     {".10 Xmit Equalizer Taps/Sym", "docsis.tlv.mcap.tapspersym",
+     {".10 Xmit Equalizer Taps/Sym", "docsis_tlv.mcap.tapspersym",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Transmit Equalizer Taps per Symbol", HFILL}
      },
     {&hf_docsis_tlv_mcap_xmit_eq_taps,
-     {".11 # Xmit Equalizer Taps", "docsis.tlv.mcap.numtaps",
+     {".11 # Xmit Equalizer Taps", "docsis_tlv.mcap.numtaps",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Number of Transmit Equalizer Taps", HFILL}
      },
     {&hf_docsis_tlv_mcap_dcc,
-     {".12 DCC Support", "docsis.tlv.mcap.dcc",
-      FT_BOOLEAN, BASE_DEC, TFS (&on_off_tfs), 0x0,
+     {".12 DCC Support", "docsis_tlv.mcap.dcc",
+      FT_BOOLEAN, BASE_NONE, TFS (&on_off_tfs), 0x0,
       "DCC Support", HFILL}
      },
     {&hf_docsis_tlv_cm_mic,
-     {"6 CM MIC", "docsis.tlv.cmmic",
+     {"6 CM MIC", "docsis_tlv.cmmic",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Cable Modem Message Integrity Check", HFILL}
      },
     {&hf_docsis_tlv_cmts_mic,
-     {"7 CMTS MIC", "docsis.tlv.cmtsmic",
+     {"7 CMTS MIC", "docsis_tlv.cmtsmic",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "CMTS Message Integrity Check", HFILL}
      },
     {&hf_docsis_tlv_vendor_id,
-     {"8 Vendor ID", "docsis.tlv.vendorid",
+     {"8 Vendor ID", "docsis_tlv.vendorid",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Vendor Identifier", HFILL}
      },
     {&hf_docsis_tlv_sw_file,
-     {"9 Software Upgrade File", "docsis.tlv.sw_upg_file",
+     {"9 Software Upgrade File", "docsis_tlv.sw_upg_file",
       FT_STRINGZ, BASE_DEC, NULL, 0x0,
       "Software Upgrade File", HFILL}
      },
     {&hf_docsis_tlv_snmp_access,
-     {"10 SNMP Write Access", "docsis.tlv.snmp_access",
+     {"10 SNMP Write Access", "docsis_tlv.snmp_access",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "SNMP Write Access", HFILL}
      },
     {&hf_docsis_tlv_snmp_obj,
-     {"11 SNMP Object", "docsis.tlv.snmp_obj",
+     {"11 SNMP Object", "docsis_tlv.snmp_obj",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "SNMP Object", HFILL}
      },
     {&hf_docsis_tlv_modem_addr,
-     {"12 Modem IP Address", "docsis.tlv.modemaddr",
+     {"12 Modem IP Address", "docsis_tlv.modemaddr",
       FT_IPv4, BASE_DEC, NULL, 0x0,
       "Modem IP Address", HFILL}
      },
     {&hf_docsis_tlv_svc_unavail,
-     {"13 Service Not Available Response", "docsis.tlv.svcunavail",
+     {"13 Service Not Available Response", "docsis_tlv.svcunavail",
       FT_BYTES, BASE_DEC, NULL, 0x0,
       "Service Not Available Response", HFILL}
      },
     {&hf_docsis_tlv_svc_unavail_classid,
-     {"Service Not Available: (Class ID)", "docsis.tlv.svcunavail.classid",
+     {"Service Not Available: (Class ID)", "docsis_tlv.svcunavail.classid",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Service Not Available (Class ID)", HFILL}
      },
     {&hf_docsis_tlv_svc_unavail_type,
-     {"Service Not Available (Type)", "docsis.tlv.svcunavail.type",
+     {"Service Not Available (Type)", "docsis_tlv.svcunavail.type",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Service Not Available (Type)", HFILL}
      },
     {&hf_docsis_tlv_svc_unavail_code,
-     {"Service Not Available (Code)", "docsis.tlv.svcunavail.code",
+     {"Service Not Available (Code)", "docsis_tlv.svcunavail.code",
       FT_UINT8, BASE_DEC, VALS(docsis_conf_code), 0x0,
       "Service Not Available (Code)", HFILL}
      },
     {&hf_docsis_tlv_cpe_ethernet,
-     {"14 CPE Ethernet Addr", "docsis.tlv.cpe_ether",
+     {"14 CPE Ethernet Addr", "docsis_tlv.cpe_ether",
       FT_ETHER, BASE_DEC, NULL, 0x0,
       "CPE Ethernet Addr", HFILL}
      },
     {&hf_docsis_tlv_bpi,
-     {"17 Baseline Privacy Encoding", "docsis.tlv.bpi",
+     {"17 Baseline Privacy Encoding", "docsis_tlv.bpi",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Baseline Privacy Encoding", HFILL}
      },
     {&hf_docsis_tlv_max_cpe,
-     {"18 Max # of CPE's", "docsis.tlv.maxcpe",
+     {"18 Max # of CPE's", "docsis_tlv.maxcpe",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Max Number of CPE's", HFILL}
      },
     {&hf_docsis_tlv_tftp_server_timestamp,
-     {"19 TFTP Server Timestamp", "docsis.tlv.tftp_time",
+     {"19 TFTP Server Timestamp", "docsis_tlv.tftp_time",
       FT_UINT32, BASE_DEC, NULL, 0x0,
       "TFTP Server TimeStamp", HFILL}
      },
     {&hf_docsis_tlv_tftp_prov_modem_address,
-     {"20 TFTP Server Provisioned Modem Addr", "docsis.tlv.tftpmodemaddr",
+     {"20 TFTP Server Provisioned Modem Addr", "docsis_tlv.tftpmodemaddr",
       FT_IPv4, BASE_DEC, NULL, 0x0,
       "TFTP Server Provisioned Modem Addr", HFILL}
      },
     {&hf_docsis_tlv_sw_upg_srvr,
-     {"21 Software Upgrade Server", "docsis.tlv.sw_upg_srvr",
+     {"21 Software Upgrade Server", "docsis_tlv.sw_upg_srvr",
       FT_IPv4, BASE_DEC, NULL, 0x0,
       "Software Upgrade Server", HFILL}
      },
     {&hf_docsis_tlv_upclsfr,
-     {"22 Upstream Classifier", "docsis.tlv.upclsfr",
+     {"22 Upstream Classifier", "docsis_tlv.upclsfr",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "22 Upstream Classifier", HFILL}
      },
     {&hf_docsis_tlv_downclsfr,
-     {"23 Downstream Classifier", "docsis.tlv.downclsfr",
+     {"23 Downstream Classifier", "docsis_tlv.downclsfr",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "23 Downstream Classifier", HFILL}
      },
     {&hf_docsis_tlv_clsfr_ref,
-     {".1 Classifier Ref", "docsis.tlv.clsfr.ref",
+     {".1 Classifier Ref", "docsis_tlv.clsfr.ref",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Classifier Reference", HFILL}
      },
     {&hf_docsis_tlv_clsfr_id,
-     {".2 Classifier ID", "docsis.tlv.clsfr.id",
+     {".2 Classifier ID", "docsis_tlv.clsfr.id",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "Classifier ID", HFILL}
      },
     {&hf_docsis_tlv_clsfr_sflow_ref,
-     {".3 Service Flow Ref", "docsis.tlv.clsfr.sflowref",
+     {".3 Service Flow Ref", "docsis_tlv.clsfr.sflowref",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "Service Flow Reference", HFILL}
      },
     {&hf_docsis_tlv_clsfr_sflow_id,
-     {".4 Service Flow ID", "docsis.tlv.clsfr.sflowid",
+     {".4 Service Flow ID", "docsis_tlv.clsfr.sflowid",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "Service Flow ID", HFILL}
      },
     {&hf_docsis_tlv_clsfr_rule_pri,
-     {".5 Rule Priority", "docsis.tlv.clsfr.rulepri",
+     {".5 Rule Priority", "docsis_tlv.clsfr.rulepri",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Rule Priority", HFILL}
      },
     {&hf_docsis_tlv_clsfr_act_state,
-     {".6 Activation State", "docsis.tlv.clsfr.actstate",
-      FT_BOOLEAN, BASE_DEC, TFS (&activation_tfs), 0x0,
+     {".6 Activation State", "docsis_tlv.clsfr.actstate",
+      FT_BOOLEAN, BASE_NONE, TFS (&activation_tfs), 0x0,
       "Classifier Activation State", HFILL}
      },
     {&hf_docsis_tlv_clsfr_dsc_act,
-     {".7 DSC Action", "docsis.tlv.clsfr.dscact",
+     {".7 DSC Action", "docsis_tlv.clsfr.dscact",
       FT_UINT8, BASE_DEC, VALS (dsc_act_vals), 0x0,
       "Dynamic Service Change Action", HFILL}
      },
     {&hf_docsis_tlv_clsfr_err,
-     {".8 Error Encodings", "docsis.tlv.clsfr.err",
+     {".8 Error Encodings", "docsis_tlv.clsfr.err",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Error Encodings", HFILL}
      },
     {&hf_docsis_tlv_clsfr_err_param,
-     {"..1 Param Subtype", "docsis.tlv.clsfr.err.param",
+     {"..1 Param Subtype", "docsis_tlv.clsfr.err.param",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Parameter Subtype", HFILL}
      },
     {&hf_docsis_tlv_clsfr_err_code,
-     {"..2 Error Code", "docsis.tlv.clsfr.err.code",
+     {"..2 Error Code", "docsis_tlv.clsfr.err.code",
       FT_UINT8, BASE_DEC, VALS(docsis_conf_code), 0x0,
       "TCP/UDP Destination Port End", HFILL}
      },
     {&hf_docsis_tlv_clsfr_err_msg,
-     {"..3 Error Message", "docsis.tlv.clsfr.err.msg",
+     {"..3 Error Message", "docsis_tlv.clsfr.err.msg",
       FT_STRINGZ, BASE_DEC, NULL, 0x0,
       "Error Message", HFILL}
      },
     {&hf_docsis_tlv_ipclsfr,
-     {".9 IP Classifier Encodings", "docsis.tlv.clsfr.ip",
+     {".9 IP Classifier Encodings", "docsis_tlv.clsfr.ip",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "IP Classifier Encodings", HFILL}
      },
     {&hf_docsis_tlv_ipclsfr_tosmask,
-     {"..1 Type Of Service Mask", "docsis.tlv.clsfr.ip.tosmask",
+     {"..1 Type Of Service Mask", "docsis_tlv.clsfr.ip.tosmask",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Type Of Service Mask", HFILL}
      },
     {&hf_docsis_tlv_ipclsfr_ipproto,
-     {"..2 IP Protocol", "docsis.tlv.clsfr.ip.ipproto",
+     {"..2 IP Protocol", "docsis_tlv.clsfr.ip.ipproto",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "IP Protocol", HFILL}
      },
     {&hf_docsis_tlv_ipclsfr_src,
-     {"..3 Source Address", "docsis.tlv.clsfr.ip.src",
+     {"..3 Source Address", "docsis_tlv.clsfr.ip.src",
       FT_IPv4, BASE_DEC, NULL, 0x0,
       "Source Address", HFILL}
      },
     {&hf_docsis_tlv_ipclsfr_dst,
-     {"..4 Destination Address", "docsis.tlv.clsfr.ip.dst",
+     {"..4 Destination Address", "docsis_tlv.clsfr.ip.dst",
       FT_IPv4, BASE_DEC, NULL, 0x0,
       "Destination Address", HFILL}
      },
     {&hf_docsis_tlv_ipclsfr_srcmask,
-     {"..5 Source Mask", "docsis.tlv.clsfr.ip.smask",
+     {"..5 Source Mask", "docsis_tlv.clsfr.ip.smask",
       FT_IPv4, BASE_DEC, NULL, 0x0,
       "Source Mask", HFILL}
      },
     {&hf_docsis_tlv_ipclsfr_dstmask,
-     {"..6 Destination Mask", "docsis.tlv.clsfr.ip.dmask",
+     {"..6 Destination Mask", "docsis_tlv.clsfr.ip.dmask",
       FT_IPv4, BASE_DEC, NULL, 0x0,
       "Destination Mask", HFILL}
      },
     {&hf_docsis_tlv_ipclsfr_sport_start,
-     {"..7 Source Port Start", "docsis.tlv.clsfr.ip.sportstart",
+     {"..7 Source Port Start", "docsis_tlv.clsfr.ip.sportstart",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "TCP/UDP Source Port Start", HFILL}
      },
     {&hf_docsis_tlv_ipclsfr_sport_end,
-     {"..8 Source Port End", "docsis.tlv.clsfr.ip.sportend",
+     {"..8 Source Port End", "docsis_tlv.clsfr.ip.sportend",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "TCP/UDP Source Port End", HFILL}
      },
     {&hf_docsis_tlv_ipclsfr_dport_start,
-     {"..9 Dest Port Start", "docsis.tlv.clsfr.ip.dportstart",
+     {"..9 Dest Port Start", "docsis_tlv.clsfr.ip.dportstart",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "TCP/UDP Destination Port Start", HFILL}
      },
     {&hf_docsis_tlv_ipclsfr_dport_end,
-     {"..10 Dest Port End", "docsis.tlv.clsfr.ip.dportend",
+     {"..10 Dest Port End", "docsis_tlv.clsfr.ip.dportend",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "TCP/UDP Destination Port End", HFILL}
      },
     {&hf_docsis_tlv_ethclsfr,
-     {".10 Ethernet Classifier Encodings", "docsis.tlv.clsfr.eth",
+     {".10 Ethernet Classifier Encodings", "docsis_tlv.clsfr.eth",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Ethernet Classifier Encodings", HFILL}
      },
     {&hf_docsis_tlv_ethclsfr_dmac,
-     {"..1 Dest Mac Address", "docsis.tlv.clsfr.eth.dmac",
+     {"..1 Dest Mac Address", "docsis_tlv.clsfr.eth.dmac",
       FT_ETHER, BASE_DEC, NULL, 0x0,
       "Destination Mac Address", HFILL}
      },
     {&hf_docsis_tlv_ethclsfr_smac,
-     {"..2 Source Mac Address", "docsis.tlv.clsfr.eth.smac",
+     {"..2 Source Mac Address", "docsis_tlv.clsfr.eth.smac",
       FT_ETHER, BASE_DEC, NULL, 0x0,
       "Source Mac Address", HFILL}
      },
     {&hf_docsis_tlv_ethclsfr_ethertype,
-     {"..3 Ethertype", "docsis.tlv.clsfr.eth.ethertype",
+     {"..3 Ethertype", "docsis_tlv.clsfr.eth.ethertype",
       FT_UINT24, BASE_HEX, NULL, 0x0,
       "Ethertype", HFILL}
      },
     {&hf_docsis_tlv_dot1qclsfr,
-     {".11 802.1Q Classifier Encodings", "docsis.tlv.clsfr.dot1q",
+     {".11 802.1Q Classifier Encodings", "docsis_tlv.clsfr.dot1q",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "802.1Q Classifier Encodings", HFILL}
      },
     {&hf_docsis_tlv_dot1qclsfr_user_pri,
-     {"..1 User Priority", "docsis.tlv.clsfr.dot1q.userpri",
+     {"..1 User Priority", "docsis_tlv.clsfr.dot1q.userpri",
       FT_UINT16, BASE_HEX, NULL, 0x0,
       "User Priority", HFILL}
      },
     {&hf_docsis_tlv_dot1qclsfr_vlanid,
-     {"..2 VLAN id", "docsis.tlv.clsfr.dot1q.ethertype",
+     {"..2 VLAN id", "docsis_tlv.clsfr.dot1q.ethertype",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "VLAN Id", HFILL}
      },
     {&hf_docsis_tlv_dot1qclsfr_vendorspec,
-     {"..43 Vendor Specific Encodings", "docsis.tlv.clsfr.dot1q.vendorspec",
+     {"..43 Vendor Specific Encodings", "docsis_tlv.clsfr.dot1q.vendorspec",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Vendor Specific Encodings", HFILL}
      },
     {&hf_docsis_tlv_clsfr_vendor_spc,
-     {".43 Vendor Specific Encodings", "docsis.tlv.clsfr.vendor",
+     {".43 Vendor Specific Encodings", "docsis_tlv.clsfr.vendor",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Vendor Specific Encodings", HFILL}
      },
     {&hf_docsis_tlv_upsflow,
-     {"24 Upstream Service Flow", "docsis.tlv.upsflow",
+     {"24 Upstream Service Flow", "docsis_tlv.upsflow",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "24 Upstream Service Flow", HFILL}
      },
     {&hf_docsis_tlv_downsflow,
-     {"25 Downstream Service Flow", "docsis.tlv.downsflow",
+     {"25 Downstream Service Flow", "docsis_tlv.downsflow",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "25 Downstream Service Flow", HFILL}
      },
     {&hf_docsis_tlv_sflow_ref,
-     {".1 Service Flow Ref", "docsis.tlv.sflow.ref",
+     {".1 Service Flow Ref", "docsis_tlv.sflow.ref",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "Service Flow Reference", HFILL}
      },
     {&hf_docsis_tlv_sflow_id,
-     {".2 Service Flow Id", "docsis.tlv.sflow.id",
+     {".2 Service Flow Id", "docsis_tlv.sflow.id",
       FT_UINT32, BASE_DEC, NULL, 0x0,
       "Service Flow Id", HFILL}
      },
     {&hf_docsis_tlv_sflow_sid,
-     {".3 Service Identifier", "docsis.tlv.sflow.sid",
+     {".3 Service Identifier", "docsis_tlv.sflow.sid",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "Service Identifier", HFILL}
      },
     {&hf_docsis_tlv_sflow_classname,
-     {".4 Service Class Name", "docsis.tlv.sflow.cname",
+     {".4 Service Class Name", "docsis_tlv.sflow.cname",
       FT_STRINGZ, BASE_HEX, NULL, 0x0,
       "Service Class Name", HFILL}
      },
     {&hf_docsis_tlv_sflow_err,
-     {".5 Error Encodings", "docsis.tlv.sflow.err",
+     {".5 Error Encodings", "docsis_tlv.sflow.err",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Error Encodings", HFILL}
      },
     {&hf_docsis_tlv_sflow_err_param,
-     {"..1 Param Subtype", "docsis.tlv.sflow.err.param",
+     {"..1 Param Subtype", "docsis_tlv.sflow.err.param",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Parameter Subtype", HFILL}
      },
     {&hf_docsis_tlv_sflow_err_code,
-     {"..2 Error Code", "docsis.tlv.sflow.err.code",
+     {"..2 Error Code", "docsis_tlv.sflow.err.code",
       FT_UINT8, BASE_DEC, VALS(docsis_conf_code), 0x0,
       "Error Code", HFILL}
      },
     {&hf_docsis_tlv_sflow_err_msg,
-     {"..3 Error Message", "docsis.tlv.sflow.err.msg",
+     {"..3 Error Message", "docsis_tlv.sflow.err.msg",
       FT_STRINGZ, BASE_DEC, NULL, 0x0,
       "Error Message", HFILL}
      },
     {&hf_docsis_tlv_sflow_qos_param,
-     {".6 QOS Parameter Set", "docsis.tlv.sflow.qos",
+     {".6 QOS Parameter Set", "docsis_tlv.sflow.qos",
       FT_UINT8, BASE_HEX, VALS (qos_param_vals), 0x0,
       "QOS Parameter Set", HFILL}
      },
     {&hf_docsis_tlv_sflow_traf_pri,
-     {".7 Traffic Priority", "docsis.tlv.sflow.trafpri",
+     {".7 Traffic Priority", "docsis_tlv.sflow.trafpri",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Traffic Priority", HFILL}
      },
     {&hf_docsis_tlv_sflow_max_sus,
      {".8 Maximum Sustained Traffic Rate (bps)",
-      "docsis.tlv.sflow.maxtrafrate",
+      "docsis_tlv.sflow.maxtrafrate",
       FT_UINT32, BASE_DEC, NULL, 0x0,
       "Maximum Sustained Traffic Rate (bps)", HFILL}
      },
     {&hf_docsis_tlv_sflow_max_burst,
-     {".9 Maximum Burst (bps)", "docsis.tlv.sflow.maxburst",
+     {".9 Maximum Burst (bps)", "docsis_tlv.sflow.maxburst",
       FT_UINT32, BASE_DEC, NULL, 0x0,
       "Maximum Burst (bps)", HFILL}
      },
     {&hf_docsis_tlv_sflow_min_traf,
-     {".10 Minimum Traffic Rate (bps)", "docsis.tlv.sflow.mintrafrate",
+     {".10 Minimum Traffic Rate (bps)", "docsis_tlv.sflow.mintrafrate",
       FT_UINT32, BASE_DEC, NULL, 0x0,
       "Minimum Traffic Rate (bps)", HFILL}
      },
     {&hf_docsis_tlv_sflow_ass_min_pkt_size,
      {".11 Assumed Min Reserved Packet Size",
-      "docsis.tlv.sflow.assumed_min_pkt_size",
+      "docsis_tlv.sflow.assumed_min_pkt_size",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "Assumed Minimum Reserved Packet Size", HFILL}
      },
     {&hf_docsis_tlv_sflow_timeout_active,
-     {".12 Timeout for Active Params (secs)", "docsis.tlv.sflow.act_timeout",
+     {".12 Timeout for Active Params (secs)", "docsis_tlv.sflow.act_timeout",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "Timeout for Active Params (secs)", HFILL}
      },
     {&hf_docsis_tlv_sflow_timeout_admitted,
      {".13 Timeout for Admitted Params (secs)",
-      "docsis.tlv.sflow.adm_timeout",
+      "docsis_tlv.sflow.adm_timeout",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "Timeout for Admitted Params (secs)", HFILL}
      },
     {&hf_docsis_tlv_sflow_max_down_latency,
      {".14 Maximum Downstream Latency (usec)",
-      "docsis.tlv.sflow.max_down_lat",
+      "docsis_tlv.sflow.max_down_lat",
       FT_UINT32, BASE_DEC, NULL, 0x0,
       "Maximum Downstream Latency (usec)", HFILL}
      },
     {&hf_docsis_tlv_sflow_max_concat_burst,
-     {".14 Max Concat Burst", "docsis.tlv.sflow.maxconcat",
+     {".14 Max Concat Burst", "docsis_tlv.sflow.maxconcat",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "Max Concatenated Burst", HFILL}
      },
     {&hf_docsis_tlv_sflow_sched_type,
-     {".15 Scheduling Type", "docsis.tlv.sflow.schedtype",
+     {".15 Scheduling Type", "docsis_tlv.sflow.schedtype",
       FT_UINT32, BASE_HEX, VALS (sched_type_vals), 0x0,
       "Scheduling Type", HFILL}
      },
     {&hf_docsis_tlv_sflow_reqxmit_pol,
-     {".16 Request/Transmission Policy", "docsis.tlv.sflow.reqxmitpol",
+     {".16 Request/Transmission Policy", "docsis_tlv.sflow.reqxmitpol",
       FT_UINT32, BASE_HEX, NULL, 0x0,
       "Request/Transmission Policy", HFILL}
      },
     {&hf_docsis_tlv_sflow_nominal_polling,
      {".17 Nominal Polling Interval(usec)",
-      "docsis.tlv.sflow.nominal_polling",
+      "docsis_tlv.sflow.nominal_polling",
       FT_UINT32, BASE_DEC, NULL, 0x0,
       "Nominal Polling Interval(usec)", HFILL}
      },
     {&hf_docsis_tlv_sflow_tolerated_jitter,
-     {".18 Tolerated Poll Jitter (usec)", "docsis.tlv.sflow.toler_jitter",
+     {".18 Tolerated Poll Jitter (usec)", "docsis_tlv.sflow.toler_jitter",
       FT_UINT32, BASE_DEC, NULL, 0x0,
       "Tolerated Poll Jitter (usec)", HFILL}
      },
     {&hf_docsis_tlv_sflow_ugs_size,
-     {".19 Unsolicited Grant Size (bytes)", "docsis.tlv.sflow.ugs_size",
+     {".19 Unsolicited Grant Size (bytes)", "docsis_tlv.sflow.ugs_size",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "Unsolicited Grant Size (bytes)", HFILL}
      },
     {&hf_docsis_tlv_sflow_nom_grant_intvl,
-     {".20 Nominal Grant Interval (usec)", "docsis.tlv.sflow.nom_grant_intvl",
+     {".20 Nominal Grant Interval (usec)", "docsis_tlv.sflow.nom_grant_intvl",
       FT_UINT32, BASE_DEC, NULL, 0x0,
       "Nominal Grant Interval (usec)", HFILL}
      },
     {&hf_docsis_tlv_sflow_tol_grant_jitter,
      {".21 Tolerated Grant Jitter (usec)",
-      "docsis.tlv.sflow.tol_grant_jitter",
+      "docsis_tlv.sflow.tol_grant_jitter",
       FT_UINT32, BASE_DEC, NULL, 0x0,
       "Tolerated Grant Jitter (usec)", HFILL}
      },
     {&hf_docsis_tlv_sflow_grants_per_intvl,
-     {".22 Grants Per Interval", "docsis.tlv.sflow.grnts_per_intvl",
+     {".22 Grants Per Interval", "docsis_tlv.sflow.grnts_per_intvl",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Grants Per Interval", HFILL}
      },
     {&hf_docsis_tlv_sflow_ip_tos_overwrite,
-     {".23 IP TOS Overwrite", "docsis.tlv.sflow.iptos_overwrite",
+     {".23 IP TOS Overwrite", "docsis_tlv.sflow.iptos_overwrite",
       FT_UINT16, BASE_HEX, NULL, 0x0,
       "IP TOS Overwrite", HFILL}
      },
     {&hf_docsis_tlv_sflow_ugs_timeref,
-     {".24 UGS Time Reference", "docsis.tlv.sflow.ugs_timeref",
+     {".24 UGS Time Reference", "docsis_tlv.sflow.ugs_timeref",
       FT_UINT32, BASE_DEC, NULL, 0x0,
       "UGS Time Reference", HFILL}
      },
     {&hf_docsis_tlv_sflow_vendor_spec,
-     {".43 Vendor Specific Encodings", "docsis.tlv.sflow.vendorspec",
+     {".43 Vendor Specific Encodings", "docsis_tlv.sflow.vendorspec",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Vendor Specific Encodings", HFILL}
      },
     {&hf_docsis_tlv_phs,
-     {"26 PHS Rules", "docsis.tlv.phs",
+     {"26 PHS Rules", "docsis_tlv.phs",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "PHS Rules", HFILL}
      },
     {&hf_docsis_tlv_phs_class_ref,
-     {".1 Classifier Reference", "docsis.tlv.phs.classref",
+     {".1 Classifier Reference", "docsis_tlv.phs.classref",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Classifier Reference", HFILL}
      },
     {&hf_docsis_tlv_phs_class_id,
-     {".2 Classifier Id", "docsis.tlv.phs.classid",
+     {".2 Classifier Id", "docsis_tlv.phs.classid",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "Classifier Id", HFILL}
      },
     {&hf_docsis_tlv_phs_sflow_ref,
-     {".3 Service flow reference", "docsis.tlv.phs.sflowref",
+     {".3 Service flow reference", "docsis_tlv.phs.sflowref",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "Service Flow Reference", HFILL}
      },
     {&hf_docsis_tlv_phs_sflow_id,
-     {".4 Service flow Id", "docsis.tlv.phs.sflowid",
+     {".4 Service flow Id", "docsis_tlv.phs.sflowid",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "Service Flow Id", HFILL}
      },
     {&hf_docsis_tlv_phs_dsc_action,
-     {".5 DSC Action", "docsis.tlv.phs.dscaction",
+     {".5 DSC Action", "docsis_tlv.phs.dscaction",
       FT_UINT8, BASE_DEC, VALS (action_vals), 0x0,
       "Dynamic Service Change Action", HFILL}
      },
     {&hf_docsis_tlv_phs_err,
-     {".6 Error Encodings", "docsis.tlv.phs.err",
+     {".6 Error Encodings", "docsis_tlv.phs.err",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Error Encodings", HFILL}
      },
     {&hf_docsis_tlv_phs_err_param,
-     {"..1 Param Subtype", "docsis.tlv.phs.err.param",
+     {"..1 Param Subtype", "docsis_tlv.phs.err.param",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Parameter Subtype", HFILL}
      },
     {&hf_docsis_tlv_phs_err_code,
-     {"..2 Error Code", "docsis.tlv.phs.err.code",
+     {"..2 Error Code", "docsis_tlv.phs.err.code",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Error Code", HFILL}
      },
     {&hf_docsis_tlv_phs_err_msg,
-     {"..3 Error Message", "docsis.tlv.phs.err.msg",
+     {"..3 Error Message", "docsis_tlv.phs.err.msg",
       FT_STRINGZ, BASE_DEC, NULL, 0x0,
       "Error Message", HFILL}
      },
     {&hf_docsis_tlv_phs_phsf,
-     {".7 PHS Field", "docsis.tlv.phs.phsf",
+     {".7 PHS Field", "docsis_tlv.phs.phsf",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "PHS Field", HFILL}
      },
     {&hf_docsis_tlv_phs_phsi,
-     {".8 PHS Index", "docsis.tlv.phs.phsi",
+     {".8 PHS Index", "docsis_tlv.phs.phsi",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "PHS Index", HFILL}
      },
     {&hf_docsis_tlv_phs_phsm,
-     {".9 PHS Mask", "docsis.tlv.phs.phsm",
+     {".9 PHS Mask", "docsis_tlv.phs.phsm",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "PHS Mask", HFILL}
      },
     {&hf_docsis_tlv_phs_phss,
-     {".10 PHS Size", "docsis.tlv.phs.phss",
+     {".10 PHS Size", "docsis_tlv.phs.phss",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "PHS Size", HFILL}
      },
     {&hf_docsis_tlv_phs_phsv,
-     {".11 PHS Verify", "docsis.tlv.phs.phsv",
-      FT_BOOLEAN, BASE_DEC, TFS (&verify_tfs), 0x0,
+     {".11 PHS Verify", "docsis_tlv.phs.phsv",
+      FT_BOOLEAN, BASE_NONE, TFS (&verify_tfs), 0x0,
       "PHS Verify", HFILL}
      },
     {&hf_docsis_tlv_phs_vendorspec,
-     {".43 PHS Vendor Specific", "docsis.tlv.phs.vendorspec",
+     {".43 PHS Vendor Specific", "docsis_tlv.phs.vendorspec",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "PHS Vendor Specific", HFILL}
      },
     {&hf_docsis_tlv_hmac_digest,
-     {"27 HMAC Digest", "docsis.tlv.hmac_digest",
+     {"27 HMAC Digest", "docsis_tlv.hmac_digest",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "HMAC Digest", HFILL}
      },
     {&hf_docsis_tlv_max_classifiers,
-     {"28 Max # of Classifiers", "docsis.tlv.maxclass",
+     {"28 Max # of Classifiers", "docsis_tlv.maxclass",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "Max # of Classifiers", HFILL}
      },
     {&hf_docsis_tlv_privacy_enable,
-     {"29 Privacy Enable", "docsis.tlv.bpi_en",
-      FT_BOOLEAN, BASE_DEC, TFS (&ena_dis_tfs), 0x0,
+     {"29 Privacy Enable", "docsis_tlv.bpi_en",
+      FT_BOOLEAN, BASE_NONE, TFS (&ena_dis_tfs), 0x0,
       "Privacy Enable", HFILL}
      },
     {&hf_docsis_tlv_auth_block,
-     {"30 Auth Block", "docsis.tlv.auth_block",
+     {"30 Auth Block", "docsis_tlv.auth_block",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Auth Block", HFILL}
      },
     {&hf_docsis_tlv_key_seq_num,
-     {"31 Key Sequence Number", "docsis.tlv.key_seq",
+     {"31 Key Sequence Number", "docsis_tlv.key_seq",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Key Sequence Number", HFILL}
      },
     {&hf_docsis_tlv_mfgr_cvc,
-     {"32 Manufacturer CVC", "docsis.tlv.mfgr_cvc",
+     {"32 Manufacturer CVC", "docsis_tlv.mfgr_cvc",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Manufacturer CVC", HFILL}
      },
     {&hf_docsis_tlv_cosign_cvc,
-     {"33 Co-Signer CVC", "docsis.tlv.cosign_cvc",
+     {"33 Co-Signer CVC", "docsis_tlv.cosign_cvc",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Co-Signer CVC", HFILL}
      },
     {&hf_docsis_tlv_snmpv3_kick,
-     {"34 SNMPv3 Kickstart Value", "docsis.tlv.snmpv3",
+     {"34 SNMPv3 Kickstart Value", "docsis_tlv.snmpv3",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "SNMPv3 Kickstart Value", HFILL}
      },
     {&hf_docsis_tlv_snmpv3_kick_name,
-     {".1 SNMPv3 Kickstart Security Name", "docsis.tlv.snmpv3.secname",
+     {".1 SNMPv3 Kickstart Security Name", "docsis_tlv.snmpv3.secname",
       FT_STRING, BASE_DEC, NULL, 0x0,
       "SNMPv3 Kickstart Security Name", HFILL}
      },
     {&hf_docsis_tlv_snmpv3_kick_publicnum,
-     {".2 SNMPv3 Kickstart Manager Public Number", "docsis.tlv.snmpv3.publicnum",
+     {".2 SNMPv3 Kickstart Manager Public Number", "docsis_tlv.snmpv3.publicnum",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "SNMPv3 Kickstart Value Manager Public Number", HFILL}
      },
     {&hf_docsis_tlv_subs_mgmt_ctrl,
-     {"35 Subscriber Management Control", "docsis.tlv.subsmgmtctrl",
+     {"35 Subscriber Management Control", "docsis_tlv.subsmgmtctrl",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Subscriber Management Control", HFILL}
      },
     {&hf_docsis_tlv_subs_mgmt_ip_table,
-     {"36 Subscriber Management CPE IP Table", "docsis.tlv.subsiptable",
+     {"36 Subscriber Management CPE IP Table", "docsis_tlv.subsiptable",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Subscriber Management CPE IP Table", HFILL}
      },
     {&hf_docsis_tlv_subs_mgmt_ip_entry,
-     {"Subscriber Management CPE IP Entry", "docsis.tlv.subsipentry",
+     {"Subscriber Management CPE IP Entry", "docsis_tlv.subsipentry",
       FT_IPv4, BASE_DEC, NULL, 0x0,
       "Subscriber Management CPE IP Entry", HFILL}
      },
     {&hf_docsis_tlv_subs_mgmt_filter_grps,
-     {"37 Subscriber Management Filter Groups", "docsis.tlv.subsfltrgrps",
+     {"37 Subscriber Management Filter Groups", "docsis_tlv.subsfltrgrps",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Subscriber Management Filter Groups", HFILL}
      },
     {&hf_docsis_tlv_vendor_spec,
-     {"43 Vendor Specific Encodings", "docsis.tlv.vendorspec",
+     {"43 Vendor Specific Encodings", "docsis_tlv.vendorspec",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Vendor Specific Encodings", HFILL}
      },
     {&hf_docsis_tlv_rng_tech,
-     {"Ranging Technique", "docsis.tlv.rng_tech",
+     {"Ranging Technique", "docsis_tlv.rng_tech",
       FT_UINT8, BASE_DEC, VALS (rng_tech_vals), 0x0,
       "Ranging Technique", HFILL}
      },
