@@ -3,7 +3,7 @@
  * Copyright 2003, Michael Lum <mlum [AT] telostech.com>
  * In association with Telos Technology Inc.
  *
- * $Id: tap-gsm_astat.c 25915 2008-08-04 16:11:17Z etxrab $
+ * $Id: tap-gsm_astat.c 26730 2008-11-07 17:37:22Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -57,6 +57,8 @@ typedef struct _gsm_a_stat_t {
     int		dtap_sms_message_type[0xff];
     int		dtap_sm_message_type[0xff];
     int		dtap_ss_message_type[0xff];
+    int		dtap_tp_message_type[0xff];
+    int		sacch_rr_message_type[0xff];
 } gsm_a_stat_t;
 
 
@@ -100,6 +102,9 @@ gsm_a_stat_packet(
 	case PD_SS:
 	    stat_p->dtap_ss_message_type[tap_p->message_type]++;
 	    break;
+	case PD_TP:
+	    stat_p->dtap_tp_message_type[tap_p->message_type]++;
+	    break;
 	default:
 	    /*
 	     * unsupported PD
@@ -108,6 +113,19 @@ gsm_a_stat_packet(
 	}
 	break;
 
+   case GSM_A_PDU_TYPE_SACCH:
+   switch (tap_p->protocol_disc)
+   {
+   case 0:
+      stat_p->sacch_rr_message_type[tap_p->message_type]++;
+      break;
+   default:
+      /* unknown Short PD */
+      break;
+   }
+   break;
+
+
     default:
 	/*
 	 * unknown PDU type !!!
@@ -265,6 +283,40 @@ gsm_a_stat_draw(
 	i++;
     }
 
+    printf("\nDTAP %s\n", gsm_a_pd_str[PD_TP]);
+    printf("Message (ID)Type                                        Number\n");
+
+    i = 0;
+    while (gsm_a_dtap_msg_tp_strings[i].strptr)
+    {
+	if (stat_p->dtap_tp_message_type[gsm_a_dtap_msg_tp_strings[i].value] > 0)
+	{
+	    printf("0x%02x  %-50s%d\n",
+		gsm_a_dtap_msg_tp_strings[i].value,
+		gsm_a_dtap_msg_tp_strings[i].strptr,
+		stat_p->dtap_tp_message_type[gsm_a_dtap_msg_tp_strings[i].value]);
+	}
+
+	i++;
+    }
+
+    printf("\nSACCH Radio Resources Management messages\n");
+    printf("Message (ID)Type                                        Number\n");
+
+    i = 0;
+    while (gsm_a_sacch_msg_rr_strings[i].strptr)
+    {
+	if (stat_p->sacch_rr_message_type[gsm_a_sacch_msg_rr_strings[i].value] > 0)
+	{
+	    printf("0x%02x  %-50s%d\n",
+		gsm_a_sacch_msg_rr_strings[i].value,
+		gsm_a_sacch_msg_rr_strings[i].strptr,
+		stat_p->sacch_rr_message_type[gsm_a_sacch_msg_rr_strings[i].value]);
+	}
+
+	i++;
+    }
+
     printf("==============================================================\n");
 }
 
